"""
Setup script for chem-tok package.

This is a minimal setup.py for backwards compatibility.
The package configuration is in pyproject.toml.
"""

from setuptools import setup

# Configuration is in pyproject.toml
setup()
